summaryrefslogtreecommitdiff
path: root/plugins/TwitterBridge
diff options
context:
space:
mode:
authorZach Copley <zach@status.net>2009-10-17 00:32:02 +0000
committerZach Copley <zach@status.net>2009-10-17 00:32:02 +0000
commit109a54c4f08177cce82ef0f4a4ec8cd41ed2ecec (patch)
tree4075875ea6c97a8f8d25cee32dbe8f665ece8b7b /plugins/TwitterBridge
parent0bbc05c1d57b0471c1d1f33ad0d1e00cd7d57e5c (diff)
Changed config flag for importing friends' timeline and added some comments
Diffstat (limited to 'plugins/TwitterBridge')
-rw-r--r--plugins/TwitterBridge/TwitterBridgePlugin.php79
1 files changed, 58 insertions, 21 deletions
diff --git a/plugins/TwitterBridge/TwitterBridgePlugin.php b/plugins/TwitterBridge/TwitterBridgePlugin.php
index 69bec0651..1a27c30cd 100644
--- a/plugins/TwitterBridge/TwitterBridgePlugin.php
+++ b/plugins/TwitterBridge/TwitterBridgePlugin.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* PHP version 5
*
@@ -18,14 +18,14 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Plugin
- * @package Laconica
- * @author Zach Copley <zach@controlyourself.ca>
+ * @package StatusNet
+ * @author Zach Copley <zach@status.net>
* @copyright 2009 Control Yourself, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
* @link http://laconi.ca/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET')) {
exit(1);
}
@@ -35,8 +35,8 @@ if (!defined('LACONICA')) {
* This class allows users to link their Twitter accounts
*
* @category Plugin
- * @package Laconica
- * @author Zach Copley <zach@controlyourself.ca>
+ * @package StatusNet
+ * @author Zach Copley <zach@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
* @link http://laconi.ca/
* @link http://twitter.com/
@@ -58,17 +58,27 @@ class TwitterBridgePlugin extends Plugin
*
* Hook for RouterInitialized event.
*
+ * @param Net_URL_Mapper &$m path-to-action mapper
+ *
* @return boolean hook return
*/
function onRouterInitialized(&$m)
{
- $m->connect('twitter/authorization', array('action' => 'twitterauthorization'));
+ $m->connect('twitter/authorization',
+ array('action' => 'twitterauthorization'));
$m->connect('settings/twitter', array('action' => 'twittersettings'));
return true;
}
+ /**
+ * Add the Twitter Settings page to the Connect Settings menu
+ *
+ * @param Action &$action The calling page
+ *
+ * @return boolean hook return
+ */
function onEndConnectSettingsNav(&$action)
{
$action_name = $action->trimmed('action');
@@ -81,38 +91,65 @@ class TwitterBridgePlugin extends Plugin
return true;
}
+ /**
+ * Automatically load the actions and libraries used by the Twitter bridge
+ *
+ * @param Class $cls the class
+ *
+ * @return boolean hook return
+ *
+ */
function onAutoload($cls)
{
- switch ($cls)
- {
- case 'TwittersettingsAction':
- case 'TwitterauthorizationAction':
- require_once(INSTALLDIR.'/plugins/TwitterBridge/' . strtolower(mb_substr($cls, 0, -6)) . '.php');
+ switch ($cls) {
+ case 'TwittersettingsAction':
+ case 'TwitterauthorizationAction':
+ include_once INSTALLDIR.'/plugins/TwitterBridge/' .
+ strtolower(mb_substr($cls, 0, -6)) . '.php';
return false;
- case 'TwitterOAuthClient':
- require_once(INSTALLDIR.'/plugins/TwitterBridge/twitteroauthclient.php');
+ case 'TwitterOAuthClient':
+ include_once INSTALLDIR.'/plugins/TwitterBridge/twitteroauthclient.php';
return false;
- default:
+ default:
return true;
}
}
+ /**
+ * Add a Twitter queue item for each notice
+ *
+ * @param Notice $notice the notice
+ * @param array $transports the list of transports (queues)
+ *
+ * @return boolean hook return
+ */
function onStartEnqueueNotice($notice, $transports)
{
array_push($transports, 'twitter');
return true;
}
+ /**
+ * Add Twitter bridge daemons to the list of daemons to start
+ *
+ * @param array $daemons the list fo daemons to run
+ *
+ * @return boolean hook return
+ *
+ */
function onGetValidDaemons($daemons)
{
- array_push($daemons, INSTALLDIR . '/plugins/TwitterBridge/daemons/twitterqueuehandler.php');
- array_push($daemons, INSTALLDIR . '/plugins/TwitterBridge/daemons/synctwitterfriends.php');
-
- if (common_config('twitterbridge', 'enabled')) {
- array_push($daemons, INSTALLDIR . '/plugins/TwitterBridge/daemons/twitterstatusfetcher.php');
+ array_push($daemons, INSTALLDIR .
+ '/plugins/TwitterBridge/daemons/twitterqueuehandler.php');
+ array_push($daemons, INSTALLDIR .
+ '/plugins/TwitterBridge/daemons/synctwitterfriends.php');
+
+ if (common_config('twitterimport', 'enabled')) {
+ array_push($daemons, INSTALLDIR
+ . '/plugins/TwitterBridge/daemons/twitterstatusfetcher.php');
}
return true;
}
-} \ No newline at end of file
+}
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* PHP version 5